==> eiffelstudio-18.07.10.1981.tar: F_code/C56/br2794.c <==
/*
 * Code for class BREAKPOINT_KEY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "br2794.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BREAKPOINT_KEY}.make */
void F3915_43799 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("make", 3914, Current, 0, 1, 52037);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {BREAKPOINT_KEY}.make_hidden */
void F3915_43800 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("make_hidden", 3914, Current, 0, 1, 52038);
	RTGC;
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current + O35910[dtype-3914]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(2);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R35907[dtype-3914])(Current, arg1);
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {BREAKPOINT_KEY}.same_breakpoint_key */
EIF_BOOLEAN F3915_43801 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("same_breakpoint_key", 3914, Current, 0, 1, 52039);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	tr1 = *(EIF_REFERENCE *)(Current);
	tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
	tb1 = F3914_43780(RTCW(tr1), tr2);
	if (tb1) {
		tb1 = *(EIF_BOOLEAN *)(RTCW(arg1) + O35910[Dtype(arg1)-3914]);
		Result = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current + O35910[Dtype(Current)-3914]) == tb1);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {BREAKPOINT_KEY}.location */
EIF_REFERENCE F3915_43803 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {BREAKPOINT_KEY}.hash_code */
EIF_INTEGER_32 F3915_43804 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("hash_code", 3914, Current, 0, 0, 52031);
	RTGC;
	RTHOOK(1);
	Result = F3913_43771(Current);
	RTHOOK(2);
	if (*(EIF_BOOLEAN *)(Current + O35910[Dtype(Current)-3914])) {
		RTHOOK(3);
		Result = eif_bit_or(Result,((EIF_INTEGER_32) 1L));
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_INTEGER_32) Result;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

/* {BREAKPOINT_KEY}.is_corrupted */
EIF_BOOLEAN F3915_43805 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("is_corrupted", 3914, Current, 0, 0, 52032);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_1_0_);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {BREAKPOINT_KEY}.routine */
EIF_REFERENCE F3915_43806 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTEAA("routine", 3914, Current, 0, 0, 52033);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = *(EIF_REFERENCE *)(RTCW(tr1));
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {BREAKPOINT_KEY}.breakable_line_number */
EIF_INTEGER_32 F3915_43807 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("breakable_line_number", 3914, Current, 0, 0, 52034);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_3_);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {BREAKPOINT_KEY}.body_index */
EIF_INTEGER_32 F3915_43808 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("body_index", 3914, Current, 0, 0, 52035);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_2_);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit2794 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-23.09.10.7341.tar: F_code/C56/br2794.c <==
/*
 * Code for class BREAKPOINT_KEY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "br2794.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BREAKPOINT_KEY}.make */
void F3884_46060 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("make", 3883, Current, 0, 1, 48040);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {BREAKPOINT_KEY}.make_hidden */
void F3884_46061 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("make_hidden", 3883, Current, 0, 1, 48041);
	RTGC;
	RTHOOK(1);
	*(EIF_BOOLEAN *)(Current + O38261[dtype-3883]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(2);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R38258[dtype-3883])(Current, arg1);
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {BREAKPOINT_KEY}.same_breakpoint_key */
EIF_BOOLEAN F3884_46062 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("same_breakpoint_key", 3883, Current, 0, 1, 48042);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	tr1 = *(EIF_REFERENCE *)(Current);
	tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
	tb1 = F4107_49754(RTCW(tr1), tr2);
	if (tb1) {
		tb1 = *(EIF_BOOLEAN *)(RTCW(arg1) + O38261[Dtype(arg1)-3883]);
		Result = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current + O38261[Dtype(Current)-3883]) == tb1);
	}
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {BREAKPOINT_KEY}.hash_code */
EIF_INTEGER_32 F3884_46065 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("hash_code", 3883, Current, 0, 0, 48045);
	RTGC;
	RTHOOK(1);
	Result = F3883_46056(Current);
	RTHOOK(2);
	if (*(EIF_BOOLEAN *)(Current + O38261[Dtype(Current)-3883])) {
		RTHOOK(3);
		ti4_1 = eif_bit_or(Result,((EIF_INTEGER_32) 1L));
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_INTEGER_32) ti4_1;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

/* {BREAKPOINT_KEY}.is_corrupted */
EIF_BOOLEAN F3884_46066 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("is_corrupted", 3883, Current, 0, 0, 48035);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = *(EIF_BOOLEAN *)(RTCW(tr1)+ _CHROFF_1_0_);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {BREAKPOINT_KEY}.routine */
EIF_REFERENCE F3884_46067 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,Result);
	RTLIU(3);
	
	RTEAA("routine", 3883, Current, 0, 0, 48036);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = *(EIF_REFERENCE *)(RTCW(tr1));
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {BREAKPOINT_KEY}.breakable_line_number */
EIF_INTEGER_32 F3884_46068 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("breakable_line_number", 3883, Current, 0, 0, 48037);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_3_);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {BREAKPOINT_KEY}.body_index */
EIF_INTEGER_32 F3884_46069 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("body_index", 3883, Current, 0, 0, 48038);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current);
	Result = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_1_0_2_);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit2794 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
